Struct rmp_serialize::encode::Encoder
[−]
[src]
pub struct Encoder<'a> { /* fields omitted */ }Represents MessagePack serialization implementation.
Note
MessagePack has no specification about how to encode variant types. Thus we are free to do whatever we want, so the given chose may be not ideal for you.
Every Rust variant value can be represented as a tuple of index and a value.
All instances of ErrorKind::Interrupted are handled by this function and the underlying
operation is retried.
Methods
impl<'a> Encoder<'a>[src]
fn new(wr: &'a mut Write) -> Encoder<'a>
Creates a new MessagePack encoder whose output will be written to the writer specified.